api.assets.v1.test_helpers.host package — Argus-Toolbelt 1.0 documentation

# api.assets.v1.test_helpers.host package

## Submodules

## api.assets.v1.test_helpers.host.add_host_asset module

`api.assets.v1.test_helpers.host.add_host_asset.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 403

`api.assets.v1.test_helpers.host.add_host_asset.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 404

`api.assets.v1.test_helpers.host.add_host_asset.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 200

`api.assets.v1.test_helpers.host.add_host_asset.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 401

## api.assets.v1.test_helpers.host.bulk_update_host_asset module

`api.assets.v1.test_helpers.host.bulk_update_host_asset.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 403

`api.assets.v1.test_helpers.host.bulk_update_host_asset.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 404

`api.assets.v1.test_helpers.host.bulk_update_host_asset.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 200

`api.assets.v1.test_helpers.host.bulk_update_host_asset.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 401

## api.assets.v1.test_helpers.host.delete_host_asset module

`api.assets.v1.test_helpers.host.delete_host_asset.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 403

`api.assets.v1.test_helpers.host.delete_host_asset.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 404

`api.assets.v1.test_helpers.host.delete_host_asset.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 200

`api.assets.v1.test_helpers.host.delete_host_asset.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 401

## api.assets.v1.test_helpers.host.get_host_asset module

`api.assets.v1.test_helpers.host.get_host_asset.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 403

`api.assets.v1.test_helpers.host.get_host_asset.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 404

`api.assets.v1.test_helpers.host.get_host_asset.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 200

`api.assets.v1.test_helpers.host.get_host_asset.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 401

## api.assets.v1.test_helpers.host.merge_host_asset module

`api.assets.v1.test_helpers.host.merge_host_asset.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+/merge, respond with HTTP 403

`api.assets.v1.test_helpers.host.merge_host_asset.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+/merge, respond with HTTP 404

`api.assets.v1.test_helpers.host.merge_host_asset.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+/merge, respond with HTTP 200

`api.assets.v1.test_helpers.host.merge_host_asset.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+/merge, respond with HTTP 401

## api.assets.v1.test_helpers.host.search_host_asset_statistics module

`api.assets.v1.test_helpers.host.search_host_asset_statistics.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/statistics, respond with HTTP 403

`api.assets.v1.test_helpers.host.search_host_asset_statistics.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/statistics, respond with HTTP 404

`api.assets.v1.test_helpers.host.search_host_asset_statistics.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/statistics, respond with HTTP 200

`api.assets.v1.test_helpers.host.search_host_asset_statistics.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/statistics, respond with HTTP 401

## api.assets.v1.test_helpers.host.search_host_assets module

`api.assets.v1.test_helpers.host.search_host_assets.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/search, respond with HTTP 403

`api.assets.v1.test_helpers.host.search_host_assets.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/search, respond with HTTP 404

`api.assets.v1.test_helpers.host.search_host_assets.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/search, respond with HTTP 200

`api.assets.v1.test_helpers.host.search_host_assets.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/search, respond with HTTP 401

## api.assets.v1.test_helpers.host.search_host_assets_simplified module

`api.assets.v1.test_helpers.host.search_host_assets_simplified.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 403

`api.assets.v1.test_helpers.host.search_host_assets_simplified.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 404

`api.assets.v1.test_helpers.host.search_host_assets_simplified.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 200

`api.assets.v1.test_helpers.host.search_host_assets_simplified.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host, respond with HTTP 401

## api.assets.v1.test_helpers.host.update_host_asset module

`api.assets.v1.test_helpers.host.update_host_asset.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 403

`api.assets.v1.test_helpers.host.update_host_asset.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 404

`api.assets.v1.test_helpers.host.update_host_asset.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 200

`api.assets.v1.test_helpers.host.update_host_asset.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/host/w+, respond with HTTP 401

## Module contents